@@ -37,7 +37,10 @@ static void MPI_Igather_prolog(CONST void *sendbuf __attribute__((unused)),
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
 
-  EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_IGATHER, (app_ptr)comm, size, rank, (app_ptr)r);
+  int ssize;
+  MPI_Type_size(sendtype, &ssize);
+  int data_size = ssize * sendcnt;
+  EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_IGATHER, (app_ptr)comm, size, rank, (app_ptr)r, data_size);
 }
 
 static int MPI_Igather_core(CONST void *sendbuf, int sendcnt, MPI_Datatype sendtype,
