@@ -14,8 +14,9 @@
 #include <pthread.h>
 #include <stdio.h>
 #include <semaphore.h>
+#include <omp.h>
 
-#include "pomp2_lib.h"
+#include "pomp-lib-dummy/pomp2_lib.h"
 #include "gomp_ev_codes.h"
 #include "eztrace.h"
 #include "pptrace.h"
@@ -117,8 +118,8 @@ void gomp_new_thread(void *arg) {
  * However, this function doesn't seem to be called. Let's implement it just in case.
  */
 void GOMP_parallel_loop_static_start(void (*fn)(void *), void * data,
-                                     unsigned num_threads, long a1, long a2,
-                                     long a3, long a4) {
+				     unsigned num_threads, long a1, long a2,
+				     long a3, long a4) {
   GOMP3_PARALLEL_LOOP_GENERIC(fn,
 			     data,
 			     arg,
@@ -129,8 +130,8 @@ void GOMP_parallel_loop_static_start(void (*fn)(void *), void * data,
 
 /* Function called when reaching  #pragma omp parallel for schedule(runtime) */
 void GOMP_parallel_loop_runtime_start(void (*fn)(void *), void * data,
-                                      unsigned num_threads, long a1, long a2,
-                                      long a3, long a4) {
+				      unsigned num_threads, long a1, long a2,
+				      long a3, long a4) {
   GOMP3_PARALLEL_LOOP_GENERIC(fn,
 			     data,
 			     arg,
@@ -141,8 +142,8 @@ void GOMP_parallel_loop_runtime_start(void (*fn)(void *), void * data,
 
 /* Function called when reaching  #pragma omp parallel for schedule(dynamic) */
 void GOMP_parallel_loop_dynamic_start(void (*fn)(void *), void * data,
-                                      unsigned num_threads, long a1, long a2,
-                                      long a3, long a4) {
+				      unsigned num_threads, long a1, long a2,
+				      long a3, long a4) {
   GOMP3_PARALLEL_LOOP_GENERIC(fn,
 			     data,
 			     arg,
@@ -153,8 +154,8 @@ void GOMP_parallel_loop_dynamic_start(void (*fn)(void *), void * data,
 
 /* Function called when reaching  #pragma omp parallel for schedule(guided) */
 void GOMP_parallel_loop_guided_start(void (*fn)(void *), void * data,
-                                     unsigned num_threads, long a1, long a2,
-                                     long a3, long a4) {
+				     unsigned num_threads, long a1, long a2,
+				     long a3, long a4) {
   GOMP3_PARALLEL_LOOP_GENERIC(fn,
 			     data,
 			     arg,
@@ -422,7 +423,7 @@ void POMP2_Parallel_join(
 }
 
 void POMP2_For_enter(POMP2_Region_handle* pomp2_handle __attribute__((unused)),
-                     const char ctc_string[] __attribute__((unused))) {
+		     const char ctc_string[] __attribute__((unused))) {
   FUNCTION_ENTRY;
   EZTRACE_EVENT_PACKED_0(EZTRACE_POMP2_FOR_ENTER);
 }
@@ -573,7 +574,7 @@ void POMP2_Task_create_end(
 }
 
 void POMP2_Task_begin(POMP2_Region_handle* pomp2_handle __attribute__((unused)),
-                      POMP2_Task_handle pomp2_task __attribute__((unused))) {
+		      POMP2_Task_handle pomp2_task __attribute__((unused))) {
   FUNCTION_ENTRY;
   EZTRACE_EVENT_PACKED_0(EZTRACE_POMP2_TASK_BEGIN);
 }
@@ -718,7 +719,7 @@ POMP2_Test_nest_lock( omp_nest_lock_t* s )
 
 void (*libPOMP2_Finalize)();
 
-START_INTERCEPT
+START_INTERCEPT_MODULE(omp)
   INTERCEPT2("GOMP_parallel_start", libGOMP_parallel_start)
   INTERCEPT2("GOMP_parallel_end", libGOMP_parallel_end)
   INTERCEPT2("GOMP_parallel_loop_static_start", libGOMP_parallel_loop_static_start)
@@ -733,12 +734,12 @@ START_INTERCEPT
   INTERCEPT2("GOMP_parallel_loop_dynamic",libGOMP_parallel_loop_dynamic)
   INTERCEPT2("GOMP_parallel_loop_guided", libGOMP_parallel_loop_guided)
   INTERCEPT2("GOMP_parallel_loop_runtime",libGOMP_parallel_loop_runtime)
-END_INTERCEPT
+END_INTERCEPT_MODULE(omp)
 
 void __gomp_init(void) __attribute__ ((constructor));
 void __gomp_init(void) {
 
-  DYNAMIC_INTERCEPT_ALL();
+  DYNAMIC_INTERCEPT_ALL_MODULE(omp);
   /* This symbol is only available if the program was compiled with eztrace_cc.
    * Use this information as a test and print a warning message.
    */
@@ -746,7 +747,7 @@ void __gomp_init(void) {
 
   if (libGOMP_critical_end && !libPOMP2_Finalize) {
     printf(
-        "Only GNU OpenMP runtime functions will be intercepted. For a more precise trace, please instrument your program with eztrace_cc.\n");
+	"Only GNU OpenMP runtime functions will be intercepted. For a more precise trace, please instrument your program with eztrace_cc.\n");
     use_pomp = 0;
   }
 
